document.addEventListener('DOMContentLoaded', () => {
  const authStatus = document.getElementById('authStatus');
  const playlistGrid = document.getElementById('playlistGrid');
  const totalProgress = document.getElementById('totalProgress');
  let isAuthenticated = false;

  // Mock authentication function
  function toggleAuth() {
    isAuthenticated = !isAuthenticated;
    updateAuthUI();
    if (isAuthenticated) {
      loadPlaylists();
    }
  }

  function updateAuthUI() {
    authStatus.innerHTML = isAuthenticated
      ? `<button id="signOut">Sign Out</button>`
      : `<button id="signIn">Sign in with Google</button>`;
    
    const button = isAuthenticated ? document.getElementById('signOut') : document.getElementById('signIn');
    button.addEventListener('click', toggleAuth);
  }

  function loadPlaylists() {
    // Mock playlist data
    const playlists = [
      { title: 'Dark Ambient Music', videos: 20, completed: 15 },
      { title: 'Gothic Architecture', videos: 15, completed: 7 },
      { title: 'Victorian Era', videos: 25, completed: 20 }
    ];

    playlistGrid.innerHTML = playlists.map(playlist => `
      <div class="playlist-card">
        <h3>${playlist.title}</h3>
        <p>${playlist.completed}/${playlist.videos} videos completed</p>
        <div class="progress-bar">
          <div class="progress" style="width: ${(playlist.completed/playlist.videos)*100}%"></div>
        </div>
      </div>
    `).join('');

    // Update total progress
    const totalVideos = playlists.reduce((acc, curr) => acc + curr.videos, 0);
    const totalCompleted = playlists.reduce((acc, curr) => acc + curr.completed, 0);
    totalProgress.style.width = `${(totalCompleted/totalVideos)*100}%`;
  }

  // Initial UI setup
  updateAuthUI();

  // Add hover effects
  document.querySelectorAll('.playlist-card').forEach(card => {
    card.addEventListener('mouseover', () => {
      card.style.transform = 'translateY(-5px)';
    });
    card.addEventListener('mouseout', () => {
      card.style.transform = 'translateY(0)';
    });
  });
});